==> actel_1.0.0.tar.gz: actel/tests/testthat/aux_assembleMatrices.R <==
aux_assembleMatrixes <- list()
aux_assembleMatrixes$maxmat$A.RS1<- read.csv(text = ',Release,River0,River1,River2,River3,River4,River5,River6,Fjord1,Fjord2,Sea1
4451,1,0,1,1,1,1,1,1,1,1,0
4453,1,0,1,1,1,1,1,1,1,1,1
4454,1,0,1,1,1,1,1,1,1,1,1
4456,1,0,1,1,1,1,1,1,1,1,1
4457,1,0,1,1,1,1,1,1,1,1,0
4459,1,0,1,1,1,1,1,1,1,1,1
4462,1,0,1,1,1,1,1,1,1,1,1
4465,1,0,1,1,1,1,1,1,1,1,1
4466,1,0,1,1,1,1,1,1,1,1,0
4469,1,0,1,1,1,1,1,1,1,1,1
4470,1,0,1,1,1,1,1,1,1,1,0
4472,1,0,1,1,1,1,1,1,1,0,0
4473,1,0,1,1,1,1,1,1,1,1,1
4474,1,0,1,1,1,1,1,1,1,1,1
4477,1,0,1,1,1,1,1,1,1,1,1
4480,1,0,1,1,1,1,1,1,1,1,1
4481,1,0,1,1,1,1,1,1,1,1,1
4484,1,0,1,1,1,1,1,1,1,1,1
4486,1,0,1,1,1,1,1,1,1,1,0
4488,1,0,1,1,1,1,1,1,1,1,1
4490,1,0,1,1,1,1,1,1,1,1,1
4492,1,0,1,1,0,1,1,1,1,1,0
4494,1,0,1,1,1,1,1,1,1,1,1
4496,1,0,1,1,1,1,1,1,1,1,1
4498,1,0,1,1,1,1,1,1,1,1,1
4499,1,0,1,1,1,1,1,1,1,1,1
4450,1,0,0,0,0,0,0,0,0,0,0
4478,1,0,0,0,0,0,0,0,0,0,0
4452,1,0,0,0,0,0,0,0,0,0,0
4464,1,0,0,0,0,0,0,0,0,0,0', row.names = 1)
aux_assembleMatrixes$maxmat$B.RS1<- read.csv(text = ',Release,River0,River1,River2,River3,River4,River5,River6,Fjord1,Fjord2,Sea1
4502,1,0,1,1,1,1,1,1,1,1,1
4503,1,0,1,1,1,1,1,1,1,1,1
4505,1,0,1,1,1,1,1,1,1,0,0
4508,1,0,1,1,1,1,1,1,1,1,1
4509,1,0,1,1,1,1,1,1,1,1,0
4510,1,0,1,1,1,1,1,1,1,1,1
4511,1,0,1,1,1,1,1,1,0,1,1
4512,1,0,1,1,1,1,1,1,1,1,0
4513,1,0,1,1,1,1,1,1,1,1,1
4514,1,0,1,1,1,1,1,1,1,1,1
4515,1,0,1,1,1,1,1,1,1,0,0
4516,1,0,1,1,1,1,1,1,1,1,1
4517,1,0,1,1,1,1,1,1,1,1,1
4518,1,0,1,1,1,1,1,1,0,0,0
4519,1,0,1,1,1,1,1,1,1,1,1
4521,1,0,1,1,1,1,1,1,1,0,0
4522,1,0,1,1,1,0,0,0,0,0,0
4524,1,0,1,1,1,1,1,1,1,1,0
4526,1,0,1,1,1,1,1,1,1,1,1
4529,1,0,1,1,1,1,1,1,1,0,0
4532,1,0,1,1,1,1,1,1,1,1,1
4534,1,0,1,1,1,0,0,0,0,0,0
4536,1,0,1,1,1,1,1,1,0,0,0
4541,1,0,1,1,1,1,1,1,1,1,1
4543,1,0,1,1,1,1,1,1,1,0,0
4545,1,0,1,1,0,1,1,1,1,1,1
4547,1,0,1,1,1,1,1,1,1,1,1
4549,1,0,1,1,1,1,1,1,1,1,0
4527,1,0,0,0,0,0,0,0,0,0,0
4520,1,0,0,0,0,0,0,0,0,0,0', row.names = 1)
aux_assembleMatrixes$minmat$A.RS1<- read.csv(text = ',Release,River0,River1,River2,River3,River4,River5,River6,Fjord1,Fjord2,Sea1
4451,1,0,1,1,1,1,1,1,1,1,0
4453,1,0,1,1,1,1,1,1,1,1,1
4454,1,0,1,1,1,1,1,1,1,1,1
4456,1,0,1,1,1,1,1,1,1,1,1
4457,1,0,1,1,1,1,1,1,1,1,0
4459,1,0,1,1,1,1,1,1,1,1,1
4462,1,0,1,1,1,1,1,1,1,1,1
4465,1,0,1,1,1,1,1,1,1,1,1
4466,1,0,1,1,1,1,1,1,1,1,0
4469,1,0,1,1,1,1,1,1,1,1,1
4470,1,0,1,1,1,1,1,1,1,1,0
4472,1,0,1,1,1,1,1,1,1,0,0
4473,1,0,1,1,1,1,1,1,1,1,1
4474,1,0,1,1,1,1,1,1,1,1,1
4477,1,0,1,1,1,1,1,1,1,1,1
4480,1,0,1,1,1,1,1,1,1,1,1
4481,1,0,1,1,1,1,1,1,1,1,1
4484,1,0,1,1,1,1,1,1,1,1,1
4486,1,0,1,1,1,1,1,1,1,1,0
4488,1,0,1,1,1,1,1,1,1,1,1
4490,1,0,1,1,1,1,1,1,1,1,1
4492,1,0,1,1,0,1,1,1,1,1,0
4494,1,0,1,1,1,1,1,1,1,1,1
4496,1,0,1,1,1,1,1,1,1,1,1
4498,1,0,1,1,1,1,1,1,1,1,1
4499,1,0,1,1,1,1,1,1,1,1,1
4450,1,0,0,0,0,0,0,0,0,0,0
4478,1,0,0,0,0,0,0,0,0,0,0
4452,1,0,0,0,0,0,0,0,0,0,0
4464,1,0,0,0,0,0,0,0,0,0,0', row.names = 1)
aux_assembleMatrixes$minmat$B.RS1<- read.csv(text = ',Release,River0,River1,River2,River3,River4,River5,River6,Fjord1,Fjord2,Sea1
4502,1,0,1,1,1,1,1,1,1,1,1
4503,1,0,1,1,1,1,1,1,1,1,1
4505,1,0,1,1,1,1,1,1,1,0,0
4508,1,0,1,1,1,1,1,1,1,1,1
4509,1,0,1,1,1,1,1,1,1,1,0
4510,1,0,1,1,1,1,1,1,1,1,1
4511,1,0,1,1,1,1,1,1,0,1,1
4512,1,0,1,1,1,1,1,1,1,1,0
4513,1,0,1,1,1,1,1,1,1,1,1
4514,1,0,1,1,1,1,1,1,1,1,1
4515,1,0,1,1,1,1,1,1,1,0,0
4516,1,0,1,1,1,1,1,1,1,1,1
4517,1,0,1,1,1,1,1,1,1,1,1
4518,1,0,1,1,1,1,1,1,0,0,0
4519,1,0,1,1,1,1,1,1,1,1,1
4521,1,0,1,1,1,1,1,1,1,0,0
4522,1,0,1,1,1,0,0,0,0,0,0
4524,1,0,1,1,1,1,1,1,1,1,0
4526,1,0,1,1,1,1,1,1,1,1,1
4529,1,0,1,1,1,1,1,1,1,0,0
4532,1,0,1,1,1,1,1,1,1,1,1
4534,1,0,1,1,1,0,0,0,0,0,0
4536,1,0,1,1,1,1,1,1,0,0,0
4541,1,0,1,1,1,1,1,1,1,1,1
4543,1,0,1,1,1,1,1,1,1,0,0
4545,1,0,1,1,0,1,1,1,1,1,1
4547,1,0,1,1,1,1,1,1,1,1,1
4549,1,0,1,1,1,1,1,1,1,1,0
4527,1,0,0,0,0,0,0,0,0,0,0
4520,1,0,0,0,0,0,0,0,0,0,0', row.names = 1)

==> actel_1.2.0.tar.gz: actel/tests/testthat/aux_assembleMatrices.R <==
aux_assembleMatrixes <- list()
aux_assembleMatrixes$maxmat$A.RS1<- read.csv(text = ',Release,A0,A1,A2,A3,A4,A5,A6,A7,A8,A9
4451,1,0,1,1,1,1,1,1,1,1,0
4453,1,0,1,1,1,1,1,1,1,1,1
4454,1,0,1,1,1,1,1,1,1,1,1
4456,1,0,1,1,1,1,1,1,1,1,1
4457,1,0,1,1,1,1,1,1,1,1,0
4459,1,0,1,1,1,1,1,1,1,1,1
4462,1,0,1,1,1,1,1,1,1,1,1
4465,1,0,1,1,1,1,1,1,1,1,1
4466,1,0,1,1,1,1,1,1,1,1,0
4469,1,0,1,1,1,1,1,1,1,1,1
4470,1,0,1,1,1,1,1,1,1,1,0
4472,1,0,1,1,1,1,1,1,1,0,0
4473,1,0,1,1,1,1,1,1,1,1,1
4474,1,0,1,1,1,1,1,1,1,1,1
4477,1,0,1,1,1,1,1,1,1,1,1
4480,1,0,1,1,1,1,1,1,1,1,1
4481,1,0,1,1,1,1,1,1,1,1,1
4484,1,0,1,1,1,1,1,1,1,1,1
4486,1,0,1,1,1,1,1,1,1,1,0
4488,1,0,1,1,1,1,1,1,1,1,1
4490,1,0,1,1,1,1,1,1,1,1,1
4492,1,0,1,1,0,1,1,1,1,1,0
4494,1,0,1,1,1,1,1,1,1,1,1
4496,1,0,1,1,1,1,1,1,1,1,1
4498,1,0,1,1,1,1,1,1,1,1,1
4499,1,0,1,1,1,1,1,1,1,1,1
4450,1,0,0,0,0,0,0,0,0,0,0
4478,1,0,0,0,0,0,0,0,0,0,0
4452,1,0,0,0,0,0,0,0,0,0,0
4464,1,0,0,0,0,0,0,0,0,0,0', row.names = 1)
aux_assembleMatrixes$maxmat$B.RS1<- read.csv(text = ',Release,A0,A1,A2,A3,A4,A5,A6,A7,A8,A9
4502,1,0,1,1,1,1,1,1,1,1,1
4503,1,0,1,1,1,1,1,1,1,1,1
4505,1,0,1,1,1,1,1,1,1,0,0
4508,1,0,1,1,1,1,1,1,1,1,1
4509,1,0,1,1,1,1,1,1,1,1,0
4510,1,0,1,1,1,1,1,1,1,1,1
4511,1,0,1,1,1,1,1,1,0,1,1
4512,1,0,1,1,1,1,1,1,1,1,0
4513,1,0,1,1,1,1,1,1,1,1,1
4514,1,0,1,1,1,1,1,1,1,1,1
4515,1,0,1,1,1,1,1,1,1,0,0
4516,1,0,1,1,1,1,1,1,1,1,1
4517,1,0,1,1,1,1,1,1,1,1,1
4518,1,0,1,1,1,1,1,1,0,0,0
4519,1,0,1,1,1,1,1,1,1,1,1
4521,1,0,1,1,1,1,1,1,1,0,0
4522,1,0,1,1,1,0,0,0,0,0,0
4524,1,0,1,1,1,1,1,1,1,1,0
4526,1,0,1,1,1,1,1,1,1,1,1
4529,1,0,1,1,1,1,1,1,1,0,0
4532,1,0,1,1,1,1,1,1,1,1,1
4534,1,0,1,1,1,0,0,0,0,0,0
4536,1,0,1,1,1,1,1,1,0,0,0
4541,1,0,1,1,1,1,1,1,1,1,1
4543,1,0,1,1,1,1,1,1,1,0,0
4545,1,0,1,1,0,1,1,1,1,1,1
4547,1,0,1,1,1,1,1,1,1,1,1
4549,1,0,1,1,1,1,1,1,1,1,0
4527,1,0,0,0,0,0,0,0,0,0,0
4520,1,0,0,0,0,0,0,0,0,0,0', row.names = 1)
aux_assembleMatrixes$minmat$A.RS1<- read.csv(text = ',Release,A0,A1,A2,A3,A4,A5,A6,A7,A8,A9
4451,1,0,1,1,1,1,1,1,1,1,0
4453,1,0,1,1,1,1,1,1,1,1,1
4454,1,0,1,1,1,1,1,1,1,1,1
4456,1,0,1,1,1,1,1,1,1,1,1
4457,1,0,1,1,1,1,1,1,1,1,0
4459,1,0,1,1,1,1,1,1,1,1,1
4462,1,0,1,1,1,1,1,1,1,1,1
4465,1,0,1,1,1,1,1,1,1,1,1
4466,1,0,1,1,1,1,1,1,1,1,0
4469,1,0,1,1,1,1,1,1,1,1,1
4470,1,0,1,1,1,1,1,1,1,1,0
4472,1,0,1,1,1,1,1,1,1,0,0
4473,1,0,1,1,1,1,1,1,1,1,1
4474,1,0,1,1,1,1,1,1,1,1,1
4477,1,0,1,1,1,1,1,1,1,1,1
4480,1,0,1,1,1,1,1,1,1,1,1
4481,1,0,1,1,1,1,1,1,1,1,1
4484,1,0,1,1,1,1,1,1,1,1,1
4486,1,0,1,1,1,1,1,1,1,1,0
4488,1,0,1,1,1,1,1,1,1,1,1
4490,1,0,1,1,1,1,1,1,1,1,1
4492,1,0,1,1,0,1,1,1,1,1,0
4494,1,0,1,1,1,1,1,1,1,1,1
4496,1,0,1,1,1,1,1,1,1,1,1
4498,1,0,1,1,1,1,1,1,1,1,1
4499,1,0,1,1,1,1,1,1,1,1,1
4450,1,0,0,0,0,0,0,0,0,0,0
4478,1,0,0,0,0,0,0,0,0,0,0
4452,1,0,0,0,0,0,0,0,0,0,0
4464,1,0,0,0,0,0,0,0,0,0,0', row.names = 1)
aux_assembleMatrixes$minmat$B.RS1<- read.csv(text = ',Release,A0,A1,A2,A3,A4,A5,A6,A7,A8,A9
4502,1,0,1,1,1,1,1,1,1,1,1
4503,1,0,1,1,1,1,1,1,1,1,1
4505,1,0,1,1,1,1,1,1,1,0,0
4508,1,0,1,1,1,1,1,1,1,1,1
4509,1,0,1,1,1,1,1,1,1,1,0
4510,1,0,1,1,1,1,1,1,1,1,1
4511,1,0,1,1,1,1,1,1,0,1,1
4512,1,0,1,1,1,1,1,1,1,1,0
4513,1,0,1,1,1,1,1,1,1,1,1
4514,1,0,1,1,1,1,1,1,1,1,1
4515,1,0,1,1,1,1,1,1,1,0,0
4516,1,0,1,1,1,1,1,1,1,1,1
4517,1,0,1,1,1,1,1,1,1,1,1
4518,1,0,1,1,1,1,1,1,0,0,0
4519,1,0,1,1,1,1,1,1,1,1,1
4521,1,0,1,1,1,1,1,1,1,0,0
4522,1,0,1,1,1,0,0,0,0,0,0
4524,1,0,1,1,1,1,1,1,1,1,0
4526,1,0,1,1,1,1,1,1,1,1,1
4529,1,0,1,1,1,1,1,1,1,0,0
4532,1,0,1,1,1,1,1,1,1,1,1
4534,1,0,1,1,1,0,0,0,0,0,0
4536,1,0,1,1,1,1,1,1,0,0,0
4541,1,0,1,1,1,1,1,1,1,1,1
4543,1,0,1,1,1,1,1,1,1,0,0
4545,1,0,1,1,0,1,1,1,1,1,1
4547,1,0,1,1,1,1,1,1,1,1,1
4549,1,0,1,1,1,1,1,1,1,1,0
4527,1,0,0,0,0,0,0,0,0,0,0
4520,1,0,0,0,0,0,0,0,0,0,0', row.names = 1)
